@@ -1,8 +1,9 @@
-package Pcore::API::Moz v0.4.0;
+package Pcore::API::Moz v0.4.1;
 
 use Pcore -dist, -class;
 use Pcore::API::Response;
-use Digest::HMAC_SHA1 qw[];    ## no critic qw[Modules::ProhibitEvilModules]
+use Digest::HMAC_SHA1 qw[];
+use Pcore::HTTP::CookieJar;
 
 has api_id      => ( is => 'ro', isa => Str,         required => 1 );
 has api_key     => ( is => 'ro', isa => Str,         required => 1 );
@@ -11,6 +12,7 @@ has proxy_pool => ( is => 'ro', isa => Maybe [ InstanceOf ['Pcore::API::ProxyPoo
 
 has _threads => ( is => 'ro', isa => PositiveOrZeroInt, default => 0, init_arg => undef );
 has _pool => ( is => 'ro', isa => ArrayRef, default => sub { [] }, init_arg => undef );
+has _cookie_jar => ( is => 'ro', isa => InstanceOf ['Pcore::HTTP::CookieJar'], default => sub { Pcore::HTTP::CookieJar->new }, init_arg => undef );
 
 sub check ( $self, $cb = undef ) {
     my $blocking_cv = defined wantarray ? AE::cv : undef;
@@ -62,6 +64,8 @@ sub url_metrics ( $self, $domains, $metric, $cb ) {
             body       => P->data->to_json($domains),
             persistent => 0,
             proxy      => $proxy,
+            useragent  => 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:47.0) Gecko/20100101 Firefox/47.0',
+            cookie_jar => $self->{_cookie_jar},
             on_finish  => sub ($res) {
                 my $api_res;
 
@@ -115,7 +119,7 @@ sub url_metrics ( $self, $domains, $metric, $cb ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    2 | 20                   | ValuesAndExpressions::RequireNumberSeparators - Long number not separated with underscores                     |
+## |    2 | 22                   | ValuesAndExpressions::RequireNumberSeparators - Long number not separated with underscores                     |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
